"""
module: slideshowfolder
created by: Johnpaul Burbank <jpburbank@tegus.ca>
Date: July 8, 2007
"""

# Zope
from zope.interface import Interface, implements, alsoProvides, providedBy
from zope.component import adapts
from zope.app.annotation.interfaces import IAnnotations, IAttributeAnnotatable
from persistent.dict import PersistentDict
try:
    #For Zope 2.10.4
    from zope.annotation.interfaces import IAnnotations, IAttributeAnnotatable
except ImportError:
    #For Zope 2.9
    from zope.app.annotation.interfaces import IAnnotations, IAttributeAnnotatable

# AT
from Products.ATContentTypes.interface.image import IATImage

#Project
from interfaces import ISlideShowFolder, IImageContainedDecider, ISlideShowSetting
from config import PROJ

from logging import info

class DefaultImageContainerDecider(object):
    """Default utility for deciding if an object is to be ISlideShowFolder."""
    implements(IImageContainedDecider)
    iprovides = (IAttributeAnnotatable, ISlideShowFolder)

    def containsImages(self, object):
        contained = object.getChildNodes()
        for child in contained:
            if IATImage.providedBy(child):
                return True
        return False

    def provideInterfaces(self, object):
        for i in self.iprovides:
            if not i.providedBy(object):
                alsoProvides(object, i)

    def run(self, ob):
        if self.containsImages(ob):
            self.provideInterfaces(ob)


class SlideShowSetting(object):
    """Implementation of ISlideShowSetting. Provides properties from the schema of the interface."""
    implements(ISlideShowSetting)
    _guarded_writes = True
    
    def __init__(self, context):
        self.context = context
        annotations = IAnnotations(self.context)
        self._metadata = annotations.get(PROJ, None)
        if self._metadata is None:
            self._metadata = PersistentDict()
            annotations[PROJ] = self._metadata
        
    def __get_slideTransition(self):
        return self._metadata.get('slideTransition')
    def __set_slideTransition(self, value):
        if not isinstance(value, unicode):
            value = unicode(value)
        self._metadata['slideTransition'] = value
    slideTransition = property(__get_slideTransition, __set_slideTransition)
    
    def __get_slideDuration(self):
        return self._metadata.get('slideDuration')
    def __set_slideDuration(self, value):
        if not isinstance(value, int):
            try:
                value = int(value)            
            except ValueError:
                value = 0
        self._metadata['slideDuration'] = value    
    slideDuration = property(__get_slideDuration, __set_slideDuration)
    
    def __get_panAmount(self):
        return self._metadata.get('panAmount')
    def __set_panAmount(self, value):
        if not isinstance(value, unicode):
            value = unicode(value) 
        self._metadata['panAmount'] = value
    panAmount = property(__get_panAmount, __set_panAmount)

    def __get_zoomAmount(self):
        return self._metadata.get('zoomAmount')
    def __set_zoomAmount(self, value):
        if not isinstance(value, unicode):
            value = unicode(value) 
        self._metadata['zoomAmount'] = value
    zoomAmount = property(__get_zoomAmount, __set_zoomAmount)
    
    def __get_transitionTime(self):
        return self._metadata.get('transitionTime')
    def __set_transitionTime(self, value):
        if not isinstance(value, int):
            try:
                value = int(value)            
            except ValueError:
                value = 0
        self._metadata['transitionTime'] = value
    transitionTime = property(__get_transitionTime, __set_transitionTime)
    
    def __get_showWidth(self):
        return self._metadata.get('showWidth')
    def __set_showWidth(self, value):
        if not isinstance(value, int):
            try:
                value = int(value)            
            except ValueError:
                value = 0
        self._metadata['showWidth'] = value
    showWidth = property(__get_showWidth, __set_showWidth)
    
    def __get_showHeight(self):
        return self._metadata.get('showHeight')
    def __set_showHeight(self, value):
        if not isinstance(value, int):
            try:
                value = int(value)            
            except ValueError:
                value = 0
        self._metadata['showHeight'] = value
    showHeight = property(__get_showHeight, __set_showHeight)
    
    def __get_thumbnails(self):
        return self._metadata.get('thumbnails')
    def __set_thumbnails(self, value):
        if not isinstance(value, bool):
            value = bool(value)
        self._metadata['thumbnails'] = value
    thumbnails = property(__get_thumbnails, __set_thumbnails)
    
    def __get_fast(self):
        return self._metadata.get('fast')
    def __set_fast(self, value):
        if not isinstance(value, bool):
            value = value = bool(value)
        self._metadata['fast'] = value
    fast = property(__get_fast, __set_fast)
    
    def __get_arrows(self):
        return self._metadata.get('arrows')
    def __set_arrows(self, value):
        if not isinstance(value, bool):
            value = value = bool(value)
        self._metadata['arrows'] = value
    arrows = property(__get_arrows, __set_arrows)


def imageContainedEventHandler(ob, event):
    from zope.component import getUtility
    decider = getUtility(IImageContainedDecider, context=ob)
    decider.run(ob)
