from base import SlideshowFolderTestCase

class TestCMFonFiveActionIntegration(SlideshowFolderTestCase):
    def afterSetUp(self):
        # remove our manager privilege
        self.logout()
        self.loginAsPortalOwner()
    
    def testSlideshowActionAvailableOnFolderWithImages(self):
        """The containsImages method on our DefaultImageContainerDecider
           class is tasked with the job of determining whether the 
           object in question contains any subobject that implements the 
           ATContentType image interfaces. 
        """
        ss_action_id = 'slideshow' # this is the id of the action our product provides
                
        actions = self.portal.portal_actions.listFilteredActionsFor(self.folder)
        action_ids = [a['id'] for a in actions['object_buttons']]
        
        # no images yet, so we shouldn't see our slideshow_settings action
        self.failIf(ss_action_id in action_ids,
                    "Uh oh! %s found in %s" % (ss_action_id, action_ids))
        
        # add our image
        self.folder.invokeFactory('Image', 'image')
        
        # recompute actions after image has been added
        actions = self.portal.portal_actions.listFilteredActionsFor(self.folder)
        action_ids = [a['id'] for a in actions['object_buttons']]
        
        # now we should see our slideshow_settings action
        self.failUnless(ss_action_id in action_ids,
                        "Uh oh! %s not found in %s" % (ss_action_id, action_ids))
    

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestCMFonFiveActionIntegration))
    return suite
