from base import SlideshowFolderTestCase

class TestSlideshowFolderProductInstall(SlideshowFolderTestCase):
    def afterSetUp(self):
        # tools
        self.skins = self.portal.portal_skins
        self.css   = self.portal.portal_css
        self.js    = self.portal.portal_javascripts
        self.types = self.portal.portal_types
        
        # product settings
        self.product_skin_layers = ('slideshowfolder','slideshowjavascript',)
        self.css_resources = ('slideshowfolder.css',) 
        self.js_resources = ('mootools.js','slideshow.js',)
        self.slideshowable_types = ('Folder',)
        
    def testSkinLayersRegistered(self):
        """Make sure the desired skin layers with templates,
           javascript, and CSS are registered with the skins tool.
        """
        registered_skin_layers = self.skins.objectIds()
        
        for layer in self.product_skin_layers:
            self.failUnless(layer in registered_skin_layers, "The layer %s is not \
                registered with the skin tool" % layer)
    
    def testSkinLayersAppearInAllThemes(self):
        """We need our product's skin directories to show up below custom as one of the called
           upon layers of our skin's properties
        """
        for selection, layers in self.skins.getSkinPaths():
            for specific_layer in self.product_skin_layers:
                self.failUnless(specific_layer in layers, "The %s layer \
                    does not appear in the layers of Plone's %s skin" % (specific_layer,selection))
        
    def testCSSRegisteryHasResources(self):
        """Make sure our CSS is registered with the portal_css tool
        """
        registered_css_items = self.css.getResourceIds()
        
        for css_item in self.css_resources:
            self.failUnless(css_item in registered_css_items, "The css file %s is not \
                registered with the portal_css tool" % css_item)
        
    def testJSRegisteryHasResources(self):
        """Make sure our JS is registered with the portal_javascripts tool
        """
        registered_js_items = self.js.getResourceIds()
        
        for js_item in self.js_resources:
            self.failUnless(js_item in registered_js_items, "The js file %s is not \
                registered with the portal_javascripts tool" % js_item)
    
    def testATFolderInTypesHasAdditionalAvailableViewMethod(self):
        """Make sure our template is an available option in the fti setup
           for each of our slideshowable content types.
        """
        for t in self.slideshowable_types:
            fti_type = getattr(self.types, t)
            self.failUnless('folder_slideshow' in fti_type.view_methods, "The folder_slideshow template is not \
                available for our slideshowable-type %s" % t)
    

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestSlideshowFolderProductInstall))
    return suite
